@@ -9,6 +9,7 @@ from timeit import time
 from pdb import set_trace
 
 # mapnik_utils
+from subprocess import Popen
 from mapnik_utils.renderer import Render
 from mapnik_utils.loader import Load
 from mapnik_utils.tools import call, color_text, color_print
@@ -52,6 +53,8 @@ class Compose(object):
         self.map = None
         self.rendered = False
         self.verbose = False
+        self.scale_factor = None
+        self.aspect_fix_mode = None
         
         self.start_time = 0
         self.load_map_time = 0
@@ -102,7 +105,7 @@ class Compose(object):
     def build(self):
         self.msg('Loading mapfile...')
         
-        builder = Load(self.mapfile,variables={},from_string=self.from_string)
+        builder = Load(self.mapfile,variables={},from_string=self.from_string,verbose=self.verbose)
         if not self.from_string:
             self.msg('Loaded %s...' % self.mapfile)
         else:
@@ -119,18 +122,22 @@ class Compose(object):
             if not selected:
                 self.output_error('Layer not found: available layers are: "%s"' % ',  '.join(disactivated))
                 
-        # handle shifts in pixel dimensions or bbox ratio
-        # need to make as an option
-        #try:
-        #    self.map.aspect_fix_mode = mapnik.aspect_fix_mode.ADJUST_CANVAS_HEIGHT
-        #except:
-        #    self.msg('aspect_fix_mode not available!')
+        # set up behavior for fixing relationship between map aspect and bbox aspect
+        if self.aspect_fix_mode:
+            if not hasattr(self.map, 'aspect_fix_mode'):
+                self.output_error('Your version of Mapnik does not support setting the aspect_fix_mode (only available in >= Mapnik 0.6.0')
+            try:
+                mode = getattr(mapnik.aspect_fix_mode,self.aspect_fix_mode.upper())
+            except AttributeError:
+                self.output_error('Error setting aspect_fix_mode, accepted values are: %s' % ', '.join(mapnik.aspect_fix_mode.names.keys()))
+            
+            self.map.aspect_fix_mode = mode
 
-        
         # zoom to max extent at beginning if we later need to 
         # zoom to a center point
         # or need to zoom to a zoom-level
         self.msg('Setting Map view...')
+        
         if self.center or not self.zoom is None:
             if self.max_extent:
                 self.msg('Zooming to max extent: %s' % self.max_extent) 
@@ -194,10 +201,10 @@ class Compose(object):
             self.build()
         
         if self.dry_run:
-            self.output_error("Dry run completed successfully...")            
+            self.output_error("Dry run completed successfully...")
 
-        renderer = Render(self.map,self.image,self.format,self.world_file,self.zip_compress)
-        if self.image:
+        renderer = Render(self.map,self.image,self.format,self.world_file,self.zip_compress,self.scale_factor)
+        if not self.image == '-':
             renderer.render_file()
         else:
             renderer.print_stream()
@@ -217,13 +224,22 @@ class Compose(object):
             call('start %s' % self.image.replace('/','\\'))
         elif platform.uname()[0] == 'Linux':
             if app:
-                call('%s %s' % (app, self.image))
+                call('%s %s' % (app,self.image))
             else:
-                resp = call('xdg-open %s' % self.image)
-                if not resp:
-                    resp = call('gthumb %s' % self.image)
-                    if not resp:
-                        call('display %s' % self.image)
+                # make blind and dumb attempt to open images, but don't block while open
+                try:
+                    cmd = 'xdg-open %s' % self.image
+                    Popen(cmd.split(' '))
+                except OSError:
+                    try:
+                        cmd = 'gthumb %s' % self.image
+                        Popen(cmd.split(' '))
+                    except OSError:
+                        try:
+                            cmd = 'display %s' % self.image
+                            Popen(cmd.split(' '))
+                        except OSError:
+                            pass
         elif platform.uname()[0] == 'Darwin':
             if app:
                 call('open %s -a %s' % (self.image, app))
@@ -260,10 +276,10 @@ class ComposeDebug(Compose):
         #self.debug_msg('mime: %s' % self.mime)
 
     def build(self):
-        try:
-            builder = super(ComposeDebug,self).build()
-        except Exception, E:
-            self.output_error(E)        
+        #try:
+        builder = super(ComposeDebug,self).build()
+        #except Exception, E:
+        #    self.output_error(E)        
         self.last_step('Loading map took... ', builder.load_map_time)
         if self.verbose:
             self.debug_msg('SRS: %s' % self.map.srs)
@@ -288,7 +304,7 @@ class ComposeDebug(Compose):
                 self.debug_msg("Layers intersecting map: [%s]" % ', '.join([l.name for l in lyrs]))
             self.debug_msg("At current scale of '%s'..." % self.map.scale())
             for lyr in lyrs:
-                if not l.visible(self.map.scale()):
+                if not lyr.visible(self.map.scale_denominator()):
                     self.debug_msg("Layer '%s' is NOT visible" % lyr.name,warn=True)
                 else:
                     self.debug_msg("layer '%s' is visible" % lyr.name)
@@ -301,10 +317,10 @@ class ComposeDebug(Compose):
         if not self.map:
             self.debug_msg('Calling build from render...')
         self.debug_msg('Starting rendering...')            
-        try:
-            renderer = super(ComposeDebug,self).render()
-        except Exception, E:
-            self.output_error(E)
+        #try:
+        renderer = super(ComposeDebug,self).render()
+        #except Exception, E:
+        #    self.output_error(E)
         self.last_step('Rendering image took... ', renderer.render_time)
         self.debug_msg('Finished rendering map to... %s' % self.image)
         self.total_time()
