@@ -6,7 +6,7 @@ from mapnik_utils.version_adapter import Mapnik
 mapnik = Mapnik()
 
 # mapnik_utils
-from projection import EasyProjection
+from mapnik_utils.projection import EasyProjection
 
 if not hasattr(mapnik,'ProjTransform'):
     from compatibility import ProjTransform
@@ -22,6 +22,9 @@ class _injector(object):
                         setattr(b,k,v)
             return type.__init__(self, name, bases, dict)
 
+if not hasattr(mapnik,'Box2d'):
+    mapnik.Box2d = mapnik.Envelope
+
 class _Map(mapnik.Map,_injector):
 
     def set_easy_srs(self,srs):
@@ -80,13 +83,14 @@ class _Map(mapnik.Map,_injector):
         c = self.layers_bounds().center()
         self.set_center_and_zoom(c.x,c.y,level=level,geographic=self.proj_obj.geographic)
     
-    @property
     def max_resolution(self):
         #self.zoom_max()
-        return self.envelope().width()/self.width    
+        map_w,map_h = self.envelope().width(),self.envelope().height()
+        return max(map_w / self.width, map_h / self.height)
 
     def get_scales(self,number):
-        return [self.max_resolution / 2 ** i for i in range(int(number))]        
+        max_res = self.max_resolution()
+        return [max_res / 2 ** i for i in range(int(number))]        
 
     def get_scale_for_zoom_level(self,level):
         return self.get_scales(level+1)[level]
@@ -98,7 +102,7 @@ class _Map(mapnik.Map,_injector):
             coords = coords.forward(self.proj_obj)
         w,h = self.width, self.height
         res = self.get_scale_for_zoom_level(level) 
-        box = mapnik.Envelope(coords.x - 0.5 * w * res,
+        box = mapnik.Box2d(coords.x - 0.5 * w * res,
                     coords.y - 0.5 * h * res, 
                     coords.x + 0.5 * w * res, 
                     coords.y + 0.5 * h * res)
@@ -106,7 +110,7 @@ class _Map(mapnik.Map,_injector):
 
     def set_center_and_radius(self,lon,lat,radius=None,geographic=True):
         coords = mapnik.Coord(lon,lat)
-        box = mapnik.Envelope(coords.x - radius,
+        box = mapnik.Box2d(coords.x - radius,
                       coords.y - radius,
                       coords.x + radius,
                       coords.y + radius)
@@ -115,7 +119,7 @@ class _Map(mapnik.Map,_injector):
         self.zoom_to_box(box)
 
     def zoom_max(self):
-        max_extent = mapnik.Envelope(-179.99999694572804,-85.0511285163245,179.99999694572804,85.0511287798066)
+        max_extent = mapnik.Box2d(-179.99999694572804,-85.0511285163245,179.99999694572804,85.0511287798066)
         if not self.proj_obj.geographic:
             max_extent = max_extent.forward(self.proj_obj)
         self.zoom_to_box(max_extent)
@@ -209,7 +213,7 @@ class _Coord(mapnik.Coord,_injector):
         trans = mapnik.ProjTransform(from_prj,to_prj)
         return trans.forward(self)
 
-class _Envelope(mapnik.Envelope,_injector):
+class _Box2d(mapnik.Box2d,_injector):
     def transform(self,from_prj,to_prj):
         trans = mapnik.ProjTransform(from_prj,to_prj)
         return trans.forward(self)
