@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 
-__version__ = '0.5.6'
-__author__ = 'Dane Springmeyer (dbsgeo [ -a- ] gmail.com)'
-__copyright__ = 'Copyright 2009, Dane Springmeyer'
+__version__ = '0.7.0'
+__author__ = 'Dane Springmeyer (dane [ -a- ] dbsgeo.com)'
+__copyright__ = 'Copyright 2010, Dane Springmeyer'
 __license__ = 'BSD'
 
 import os
@@ -25,10 +25,10 @@ Read MML in verbose mode
  $ %prog mapfile.mml image.png -v
 
 Read MML, pipe to image
- $ %prog mapfile.mml --pipe > image.png
+ $ %prog mapfile.mml - > image.png
 
 Accept piped XML
-$ <xml stream> | %prog image.png
+$ <xml stream> | %prog - image.png
 
 """, version='%prog ' + __version__)
 
@@ -149,10 +149,6 @@ parser.add_option('--no-color', dest='no_color',
 parser.add_option('--no-open', dest='no_open',
                   action='store_true', default=False,
                   help='Skip opening of image in default viewer')
-
-parser.add_option('--pipe', dest='pipe',
-                  action='store_true', default=False,
-                  help='Pipe image to byte stream instead of writing to file')
                   
 parser.add_option('--fonts',
                   type='string', # actually results in a comma-delimited list
@@ -167,7 +163,17 @@ parser.add_option('--mapnik-version', dest='mapnik_version',
 parser.add_option('--zip', dest='zip_compress',
                   action='store_true', default=False,
                   help='Apply zip compression to output image (and other files by same name)')
-    
+
+parser.add_option('--scale-factor', dest='scale_factor',
+                  type='float',
+                  help='Pass a scale factor to the Mapnik renderer (experimental)',
+                  action='store')
+
+parser.add_option('--aspect-fix-mode', dest='aspect_fix_mode',
+                  type='string',
+                  help='Pass an aspect_fix_mode string (case-insensitive match of http://media.mapnik.org/api_docs/python/mapnik._mapnik.aspect_fix_mode-class.html)',
+                  action='store')
+                      
 if __name__ == '__main__':
     (options, args) = parser.parse_args()
     
@@ -176,8 +182,18 @@ if __name__ == '__main__':
     # control usage of either mapnik or mapnik2
     from mapnik_utils.version_adapter import Mapnik
     mapnik = Mapnik(options.mapnik_version)
+    
+    if options.scale_factor:
+        if not mapnik.mapnik_version() >= 800:
+            parser.error('\nPassing a scale factor requires at least mapnik >= 0.8.0 (aka Mapnik2)\n')
+    
+    if len(args) == 0:
+        parser.error('\nPlease provide the path to a Mapnik xml or Cascadenik mml file\n')
+    
+    elif len(args) == 1 and not options.dry_run:
+        parser.error('\nPlease provide an output image name\n')
 
-    if not sys.stdin.isatty():
+    if args[0] == '-' and not sys.stdin.isatty():
         xml = sys.stdin.read()
         if hasattr(mapnik,'load_map_from_string'):
             options.from_string = True
@@ -187,18 +203,21 @@ if __name__ == '__main__':
             (handle, mapfile) = tempfile.mkstemp('.xml', 'mapfile_string')
             os.close(handle)
             open(mapfile, 'w').write(xml)
-        if len(args) > 0:
-            options.image = args[0]
-    elif len(args) == 0:
-        parser.error('\n\nPlease provide the path to a Mapnik xml or Cascadenik mml file\n')
     else:
         mapfile = args[0]
-        if len(args) > 1:
-            options.image = args[1]
+
+    if len(args) > 1:
+        options.image = args[1]
+        if options.image == '-':
+            options.pipe = True
+        else:
+            options.pipe = False
            
     options.width, options.height = options.dimensions
     if not options.format and hasattr(options,'image'):
-        if not options.image.endswith('png'):
+        if options.image == '-':
+            options.format = 'png'
+        elif not options.image.endswith('png'):
             try:
                 options.format = options.image.split('.')[-1]
             except:
@@ -210,13 +229,7 @@ if __name__ == '__main__':
         if options.no_open:
             nik_map.render()
         else:
-            if hasattr(options,'image'):
-                nik_map.open()
-            else:
-                if not options.pipe and not options.dry_run:
-                    parser.error('\n\nPlease provide the path to an output image.\n')
-                else:
-                    nik_map.render()
+            nik_map.open()
     
     if options.profile:
         import cProfile
